@@ -3,7 +3,7 @@
 from astropy.coordinates import BarycentricMeanEcliptic
 
 """The coordinate system used by the framework"""
-DEFAULT_COORDINATE_SYSTEM = BarycentricMeanEcliptic
+DEFAULT_COORDINATE_SYSTEM = BarycentricMeanEcliptic()
 
 """The time scale used by the framework"""
 DEFAULT_TIME_SCALE = "tdb"
