@@ -10,11 +10,12 @@ from ducc0 import healpix
 import healpy  # We need healpy.read_map
 
 import litebird_sim as lbs
+
 from toast.todmap import OpMapMaker  # noqa: F401
 from toast.tod.interval import Interval
+import toast.mpi
 
-if lbs.MPI_ENABLED:
-    import toast.mpi
+toast.mpi.use_mpi = lbs.MPI_ENABLED
 
 
 @dataclass
@@ -222,7 +223,7 @@ class _Toast2FakeData:
         self.bore2spin_quat = bore2spin_quat
         self.nside = nside
         if lbs.MPI_ENABLED:
-            self.comm = toast.mpi.Comm(lbs.MPI_COMM_WORLD)
+            self.comm = toast.mpi.Comm(world=lbs.MPI_COMM_WORLD)
         else:
             CommWorld = namedtuple(
                 "CommWorld", ["comm_world", "comm_group", "comm_rank", "comm_size"]
